#ifndef __LED_STRIP_HPP__
#define __LED_STRIP_HPP__
#include <Arduino.h>

#if defined(ARDUINO_AVR_ATTINYX5) || defined(ARDUINO_AVR_ATTINYX41)
#include <tinyNeoPixel_Static.h>
#else
#include <Adafruit_NeoPixel.h>
#endif /* defined(ARDUINO_AVR_ATTINYX5) || defined(ARDUINO_AVR_ATTINYX41) */

#include "pin_map.hpp"

/* Leds */

/* Led ring color and led count state */
typedef struct {
  uint16_t ledOnMin;
  uint16_t ledOnMax;
  uint16_t hue;
  uint8_t saturation;
  uint8_t brightness;
} LedRingColorState_t;

uint8_t const PresetMax{8};

// https://hslpicker.com/          = {0, 40, 50, 110, 240, 280, 310, 360 for white}
uint16_t const PresetHue[PresetMax] = {0, 7282, 9102, 20025, 43691, 50972, 56434, 65535};

uint8_t const PresetLevelMax{3};

uint8_t const PresetBrightness[PresetLevelMax] = {16, 64, 127};

/* Preset state */
typedef struct {
  uint8_t index;
  uint8_t level;
} PresetState_t;

class LedStrip {
private:
  uint16_t static const LedCount{24};

/*  IO Objects */
#if defined(ARDUINO_AVR_ATTINYX5) || defined(ARDUINO_AVR_ATTINYX41)
  byte pixels[LedCount * 3];
  tinyNeoPixel ledRing{LedCount, LedPin, NEO_GRB + NEO_KHZ800, pixels};
#else
  Adafruit_NeoPixel ledRing{LedCount, LedPin, NEO_GRB + NEO_KHZ800};
#endif /* defined(ARDUINO_AVR_ATTINYX5) || defined(ARDUINO_AVR_ATTINYX41) */

  LedRingColorState_t ledRingColorState = {
      .ledOnMin = 0, .ledOnMax = LedCount / 2, .hue = 0, .saturation = 255, .brightness = 16};
  PresetState_t presetState = {.index = 0, .level = 0};

public:
  LedStrip(/* args */) {}
  ~LedStrip() {}
  int setup();
  void fill(uint32_t c = 0, uint16_t first = 0, uint16_t count = 0);
};

#endif /* __LED_STRIP_HPP__ */
